@@ -45,7 +45,6 @@ except:
 
 # Check version of plotly, if is greater than 4.9 gitly will use kaleido, if not will use urca
 if ( compareVersion( version,  '4.9.0') > 0 ):
-    print('Updating kaleido' )
     os.system('pip install -U kaleido')
 else:
     print('Plotly version fewer than 4.9.0, orca module will be necessary')
@@ -84,9 +83,6 @@ class GitlyPlotter:
             self.default_S = default_scale
 
         import plotly
-
-        print(plotly.__version__)
-        
         if (compareVersion( plotly.__version__,  '4.9.0') <= 0 ):
             self.use_kaleido = False
         else:
